Client

Struct Client 

pub struct Client { /* private fields */ }
Apache Livy REST API client

Implementations

Source

impl Client

pub fn new( url: &str, gssnegotiate: Option<bool>, username: Option<String>, ) -> Client

Constructs a new Client.

Examples
use livy::client::Client;

let client = Client::new("http://example.com:8998", None, None);
use livy::client::Client;

let client = Client::new("http://example.com:8998", Some(true), Some("username".to_string()));
pub fn get_sessions( &self, from: Option<i64>, size: Option<i64>, ) -> Result<Sessions, String>

Gets information of sessions and returns it.

HTTP Request

GET /sessions

pub fn create_session( &self, new_session_request: NewSessionRequest, ) -> Result<Session, String>

Creates a new session.

HTTP Request

POST /sessions

pub fn get_session(&self, session_id: i64) -> Result<Session, String>

Gets information of a single session and returns it.

HTTP Request

GET /sessions/{sessionId}

pub fn get_session_state( &self, session_id: i64, ) -> Result<SessionStateOnly, String>

Gets session state information of a single session and returns it.

HTTP Request

GET /sessions/{sessionId}/state

pub fn kill_session(&self, session_id: i64) -> Result<SessionKillResult, String>

Kills the session whose id is equal to session_id.

HTTP Request

DELETE /sessions/{sessionId}

pub fn get_session_log( &self, session_id: i64, from: Option<i64>, size: Option<i64>, ) -> Result<SessionLog, String>

Gets the log lines of a single session and returns them.

HTTP Request

GET /sessions/{sessionId}/log

pub fn get_statements(&self, session_id: i64) -> Result<Statements, String>

Gets the statements of a single session and returns them.

HTTP Request

GET /sessions/{sessionId}/statements

pub fn run_statement( &self, session_id: i64, run_statement_request: RunStatementRequest, ) -> Result<Statement, String>

Runs a statement in a session.

HTTP Request

POST /sessions/{sessionId}/statements

pub fn get_statement( &self, session_id: i64, statement_id: i64, ) -> Result<Statement, String>

Gets a single statement of a single session and returns it.

HTTP Request

GET /sessions/{sessionId}/statements/{statementId}

pub fn cancel_statement( &self, session_id: i64, statement_id: i64, ) -> Result<StatementCancelResult, String>

Cancel a single statement.

HTTP Request

POST /sessions/{sessionId}/statements/{statementId}/cancel

pub fn get_batches( &self, from: Option<i64>, size: Option<i64>, ) -> Result<Batches, String>

Gets information of batches and returns it.

HTTP Request

GET /batches

pub fn create_batch( &self, new_batch_request: NewBatchRequest, ) -> Result<Batch, String>

Creates a new batch.

HTTP Request

POST /batches

pub fn get_batch(&self, batch_id: i64) -> Result<Batch, String>

Gets a batch and returns it.

HTTP Request

GET /batches/{batchId}

pub fn get_batch_state(&self, batch_id: i64) -> Result<BatchStateOnly, String>

Gets the state of batch session.

HTTP Request

GET /batches/{batchId}/state

pub fn kill_batch(&self, batch_id: i64) -> Result<BatchKillResult, String>

Kills the batch job.

HTTP Request

DELETE /batches/{batchId}

pub fn get_batch_log( &self, batch_id: i64, from: Option<i64>, size: Option<i64>, ) -> Result<BatchLog, String>

Gets the log lines from a batch and returns them.

HTTP Request

GET /batches/{batchId}/log